# eric7.WebBrowser.JavaScript.PasswordManagerJsObject

Module implementing the Python side for calling the password manager.

### Global Attributes

None

### Classes

PasswordManagerJsObject | Class implementing the Python side for calling the password manager.

### Functions

None

## PasswordManagerJsObject

Class implementing the Python side for calling the password manager.

### Derived from

QObject

### Class Attributes

None

### Class Methods

None

### Methods

PasswordManagerJsObject | Constructor
formSubmitted | Public slot passing form data to the password manager.

### Static Methods

None

#### PasswordManagerJsObject (Constructor)

PasswordManagerJsObject(parent=None)

Constructor

parent (ExternalJsObject)
  reference to the parent object

#### PasswordManagerJsObject.formSubmitted

formSubmitted(urlStr, userName, password, data)

Public slot passing form data to the password manager.

urlStr (str)
  form submission URL
userName (str)
  name of the user
password (str)
  user password
data (QByteArray)
  data to be submitted

Up